==> qrl-0.57.0.tar.gz: qrl-0.57.0/travis/jessie/build.sh <==
#!/bin/sh

set -e

echo "Creating/fixing home"
sudo mkdir -p ${HOME}
sudo -E chown -R $(whoami):$(whoami) ${HOME}
sudo -E chmod -R a+rxw ${HOME}

cd /travis

sudo -H pip3 install -r requirements.txt
sudo -H pip3 install -r test-requirements.txt
sudo -H pip3 install setuptools

echo
echo
echo "****************************************************************"
echo "****************************************************************"
python3 --version
cmake --version
pip3 --version
echo "****************************************************************"
echo "****************************************************************"
echo
echo

if [ -n "${STYLECHECK:+1}" ]; then
    echo "****************************************************************"
    echo "****************************************************************"
    echo "                          STYLE CHECK"
    echo "****************************************************************"
    echo "****************************************************************"
    sudo pip install -U pycodestyle flake8
    flake8
    pycodestyle
fi

if [ -n "${TEST:+1}" ]; then
    echo "****************************************************************"
    echo "****************************************************************"
    echo "                            TEST"
    echo "****************************************************************"
    echo "****************************************************************"
    python3 setup.py test
fi

if [ -n "${DEPLOY:+1}" ]; then
    echo "****************************************************************"
    echo "****************************************************************"
    echo "                           DEPLOY"
    echo "****************************************************************"
    echo "****************************************************************"
    python3 setup.py sdist
fi

==> qrl-0.58.2.tar.gz: qrl-0.58.2/travis/jessie/build.sh <==
#!/bin/sh

set -e

echo "Creating/fixing home"
sudo mkdir -p ${HOME}
sudo -E chown -R $(whoami):$(whoami) ${HOME}
sudo -E chmod -R a+rxw ${HOME}

cd /travis

sudo -H pip3 install -r requirements.txt
sudo -H pip3 install -r test-requirements.txt
sudo -H pip3 install setuptools

echo
echo
echo "****************************************************************"
echo "****************************************************************"
python3 --version
cmake --version
pip3 --version
echo "****************************************************************"
echo "****************************************************************"
echo
echo

if [ -n "${STYLECHECK:+1}" ]; then
    echo "****************************************************************"
    echo "****************************************************************"
    echo "                          STYLE CHECK"
    echo "****************************************************************"
    echo "****************************************************************"
    sudo pip install -U pycodestyle flake8 | cat
    flake8
    pycodestyle
fi

if [ -n "${TEST:+1}" ]; then
    echo "****************************************************************"
    echo "****************************************************************"
    echo "                            TEST"
    echo "****************************************************************"
    echo "****************************************************************"
    python3 setup.py test 2>/dev/null
fi

if [ -n "${DEPLOY:+1}" ]; then
    echo "****************************************************************"
    echo "****************************************************************"
    echo "                           DEPLOY"
    echo "****************************************************************"
    echo "****************************************************************"
    python3 setup.py sdist
fi
